

def print_input(my_input: str):
    """This simply prints a useless sentence and the given input.

    Args:
        my_input (str): input to print
    """
    print(f'The this prints out the input: {my_input}')





class Person():
    def __init__(self, fname: str, lname: str) -> None:
        """This is a person

        Args:
            fname (str): first name
            lname (str): last name
        """
        self.fname = fname
        self.lname = lname

        self.print_main_greeting()

    def print_main_greeting(self):
        """Prints a greeting.
        """
        print(f'Welcome {self.fname} {self.lname}!')


class Student(Person):
    def __init__(self, fname: str, lname: str, semester: int) -> None:
        """This is a student

        Args:
            fname (str): first name
            lname (str): last name
            semester (int): Students semester
        """
        super().__init__(fname, lname)
        self.semester = semester

        self.print_greeting()

    def print_greeting(self):
        """Prints a more specific greeting
        """
        print(f'Welcome {self.fname} {self.lname} to the {str(self.semester)}. semester!')

    def return_greeting(self):
        """Returns a more specific greeting
        """
        return f'Welcome {self.fname} {self.lname} to the {str(self.semester)}. semester!'



from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.13'
DESCRIPTION = 'Data wrangling on files read with pyreadstat'

with open("README.md", "r") as fh:
    LONG_DESCRIPTION = fh.read()

# Setting up
setup(
    name="metatables",
    version=VERSION,
    author="Joël Grosjean",
    author_email="<joel.grosjean@gfs-zh.ch>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[
        "pyreadstat >= 1.1",
        "pandas >= 1.3"
    ],
    extras_require={
        "dev": [
            "pytest >= 3.7",
            "check-manifest",
            "twine",
            "sphinx",
            "sphinx-rtd-theme",
            "pdoc3"
        ]
    },
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: Apache Software License"
    ],
    project_urls={
        'Repository': 'https://github.com/tez4/metatables',
        'Documentation': 'https://tez4.github.io/metatables/'
    }
)



import pyreadstat
from metatables import MetaTable

if __name__ == '__main__':
    df1, meta1 = pyreadstat.read_sav('./data/fertig_R.sav')

    print(meta1.column_names_to_labels['F5_01'])
    print(meta1.variable_value_labels['F5_01'])

    x = MetaTable(df1, meta1)
    x.val_lab(['F5_01', 'F5_02'], {1: 'Fish', 2: 'Chips'})
    x.var_lab(['F5_01', 'F5_02'], 'New Label')
    x.select_columns(['F5_01', 'F5_02'])
    x.show('F5_01')
    x.write_sav('./data/fertig_test.sav')
